rsp: Compiles an RSP document
Description
Compiles an RSP document.
Usage
"rsp"(filename=NULL, path=NULL, text=NULL, response=NULL, ..., envir=parent.frame(), outPath=".", postprocess=TRUE, verbose=FALSE)
Arguments
filename, path
The filename and (optional) path of the
RSP document to be compiled.
text
A character vector of RSP code to be processed,
iff argument filename is not given. response
Specifies where the final output should be sent.
If argument text is given, then stdout() is used.
Otherwise, the output defaults to that of the type-specific compiler. ...
Additional arguments passed to the type-specific compiler.
envir
The environment in which the RSP document is evaluated. outPath
The output and working directory.
postprocess
If TRUE, and a postprocessing method exists for
the generated document type, it is postprocessed as well. Value
If argument response specifies a file output, then the
absolute pathname of the generated file is returned.
If argument text is specified, then the generated string
is returned (invisibly).
Postprocessing
For some document types, the rsp() method automatically
postprocesses the generated document as well.